@@ -126,6 +126,18 @@ find_formula.gamlss <- function(x, ...) {
 }
 
 
+#' @importFrom stats as.formula
+#' @export
+find_formula.bamlss <- function(x, ...) {
+  f <- stats::formula(x)
+
+  .compact_list(list(
+    conditional = stats::as.formula(.safe_deparse(f$mu$formula)),
+    sigma = stats::as.formula(paste0("~", as.character(f$sigma$formula)[3]))
+  ))
+}
+
+
 
 #' @export
 find_formula.gamm <- function(x, ...) {
@@ -458,6 +470,16 @@ find_formula.zerotrunc <- function(x, ...) {
 
 
 
+#' @export
+find_formula.clmm2 <- function(x, ...) {
+  list(
+    conditional = stats::as.formula(.safe_deparse(attr(x$location, "terms", exact = TRUE))),
+    random  = stats::as.formula(paste0("~", parse(text = .safe_deparse(x$call))[[1]]$random))
+  )
+}
+
+
+
 #' @export
 find_formula.clm2 <- function(x, ...) {
   list(conditional = attr(x$location, "terms", exact = TRUE))
@@ -531,6 +553,36 @@ find_formula.glmmTMB <- function(x, ...) {
 
 
 
+#' @export
+find_formula.nlmerMod <- function(x, ...) {
+  if (!requireNamespace("lme4", quietly = TRUE)) {
+    stop("To use this function, please install package 'lme4'.")
+  }
+
+  f.cond <- stats::formula(x)
+  f.random <- lapply(lme4::findbars(f.cond), function(.x) {
+    f <- .safe_deparse(.x)
+    stats::as.formula(paste0("~", f))
+  })
+
+  if (length(f.random) == 1) {
+    f.random <- f.random[[1]]
+  }
+
+  fx <- .get_fixed_effects(f.cond)
+
+  f.cond <- stats::as.formula(gsub("(.*)(~)(.*)~(.*)", "\\1\\2\\4", fx))
+  f.nonlin <- stats::as.formula(paste0("~", .trim(gsub("(.*)~(.*)~(.*)", "\\2", fx))))
+
+  .compact_list(list(
+    conditional = f.cond,
+    nonlinear = f.nonlin,
+    random = f.random
+  ))
+}
+
+
+
 #' @export
 find_formula.merMod <- function(x, ...) {
   if (!requireNamespace("lme4", quietly = TRUE)) {
@@ -743,6 +795,7 @@ find_formula.BFBayesFactor <- function(x, ...) {
 
 
 
+
 .get_brms_formula <- function(f) {
   if (!requireNamespace("lme4", quietly = TRUE)) {
     stop("To use this function, please install package 'lme4'.")
@@ -787,6 +840,7 @@ find_formula.BFBayesFactor <- function(x, ...) {
 
 
 
+
 .get_stanmv_formula <- function(f) {
   if (!requireNamespace("lme4", quietly = TRUE)) {
     stop("To use this function, please install package 'lme4'.")
@@ -812,6 +866,8 @@ find_formula.BFBayesFactor <- function(x, ...) {
 
 
 
+# Find formula for zero-inflated regressions, where
+# zero-inflated part is separated by | from count part
 .zeroinf_formula <- function(x) {
   f <- tryCatch({
     stats::formula(x)
@@ -837,18 +893,7 @@ find_formula.BFBayesFactor <- function(x, ...) {
   ## TODO could be extended to all find_formula()
 
   # fix dot-formulas
-  c.form <- tryCatch({
-    if (as.character(c.form[3]) == ".") {
-      resp <- .safe_deparse(c.form[2])
-      pred <- setdiff(colnames(.get_data_from_env(x)), resp)
-      c.form <- stats::as.formula(paste(resp, "~", paste0(pred, collapse = " + ")))
-    }
-    c.form
-  },
-  error = function(e) {
-    c.form
-  }
-  )
+  c.form <- .dot_formula(f = c.form, model = x)
 
   # fix dot-formulas
   zi.form <- tryCatch({
@@ -867,3 +912,23 @@ find_formula.BFBayesFactor <- function(x, ...) {
 
   .compact_list(list(conditional = c.form, zero_inflated = zi.form))
 }
+
+
+
+# try to guess "full" formula for dot-abbreviation, e.g.
+# lm(mpg ~., data = mtcars)
+.dot_formula <- function(f, model) {
+  # fix dot-formulas
+  tryCatch({
+    if (as.character(f[3]) == ".") {
+      resp <- .safe_deparse(f[2])
+      pred <- setdiff(colnames(.get_data_from_env(model)), resp)
+      f <- stats::as.formula(paste(resp, "~", paste0(pred, collapse = " + ")))
+    }
+    f
+  },
+  error = function(e) {
+    f
+  }
+  )
+}
