@@ -13,7 +13,6 @@
 #' mtcars$weight <- rnorm(nrow(mtcars), 1, .3)
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars, weights = weight)
 #' get_weights(m)
-#'
 #' @export
 get_weights <- function(x, ...) {
   UseMethod("get_weights")
@@ -23,34 +22,49 @@ get_weights <- function(x, ...) {
 #' @export
 get_weights.default <- function(x, ...) {
   w <- NULL
-  tryCatch(
-    {
-      w <- stats::weights(x)
-    },
-    error = function(x) { NULL },
-    warning = function(x) { NULL },
-    finally = function(x) { NULL }
+  tryCatch({
+    w <- stats::weights(x)
+  },
+  error = function(x) {
+    NULL
+  },
+  warning = function(x) {
+    NULL
+  },
+  finally = function(x) {
+    NULL
+  }
   )
 
   if (is.null(w)) {
-    tryCatch(
-      {
-        w <- stats::model.frame(x)[["(weights)"]]
-      },
-      error = function(x) { NULL },
-      warning = function(x) { NULL },
-      finally = function(x) { NULL }
+    tryCatch({
+      w <- stats::model.frame(x)[["(weights)"]]
+    },
+    error = function(x) {
+      NULL
+    },
+    warning = function(x) {
+      NULL
+    },
+    finally = function(x) {
+      NULL
+    }
     )
   }
 
   if (is.null(w)) {
-    tryCatch(
-      {
-        w <- .get_data_from_env(x)[[find_weights(x)]]
-      },
-      error = function(x) { NULL },
-      warning = function(x) { NULL },
-      finally = function(x) { NULL }
+    tryCatch({
+      w <- .get_data_from_env(x)[[find_weights(x)]]
+    },
+    error = function(x) {
+      NULL
+    },
+    warning = function(x) {
+      NULL
+    },
+    finally = function(x) {
+      NULL
+    }
     )
   }
 
@@ -65,4 +79,4 @@ get_weights.brmsfit <- function(x, ...) {
   if (!is.null(w)) {
     get_data(x)[[w]]
   }
-}
\ No newline at end of file
+}
