@@ -22,8 +22,13 @@ is_model <- function(x) {
     x,
     c(
       "aareg",
+      "anova",
       "aov",
       "aovlist",
+      "Arima",
+      "bamlss",
+      "bamlss.frame",
+      "bayesx",
       "BBmm",
       "BBreg",
       "betareg",
@@ -31,23 +36,35 @@ is_model <- function(x) {
       "bglmerMod",
       "biglm",
       "bigglm",
+      "blavaan",
       "blmerMod",
+      "bracl",
+      "brglmFit",
       "brmsfit",
+      "brmultinom",
       "btergm",
       "cch",
       "censReg",
+      "cgam",
+      "cgamm",
       "clm",
       "clm2",
       "clmm",
+      "clmm2",
+      "complmrob",
       "confusionMatrix",
       "coxme",
       "coxph",
       "crch",
       "crq",
       "drc",
+      "emmGrid",
+      "epi.2by2",
       "ergm",
       "feis",
       "felm",
+      "fitdistr",
+      "flexsurvreg",
       "gam",
       "Gam",
       "gamlss",
@@ -61,6 +78,7 @@ is_model <- function(x) {
       "glm",
       "glmerMod",
       "glmmadmb",
+      "glmmLasso",
       "glmmPQL",
       "glmmTMB",
       "glmnet",
@@ -68,10 +86,12 @@ is_model <- function(x) {
       "glmRob",
       "gls",
       "gmnl",
+      "gmm",
       "htest",
       "hurdle",
       "iv_robust",
       "ivreg",
+      "lavaan",
       "lm",
       "lm_robust",
       "lme",
@@ -83,10 +103,10 @@ is_model <- function(x) {
       "lmodel2",
       "lqmm",
       "lrm",
-      "ols",
-      "orcutt",
+      "manova",
       "mclogit",
       "mmclogit",
+      "mcmc",
       "MCMCglmm",
       "mediate",
       "merMod",
@@ -97,9 +117,12 @@ is_model <- function(x) {
       "mlm",
       "mlogit",
       "multinom",
+      "mvr",
       "negbin",
       "nlrq",
       "nls",
+      "ols",
+      "orcutt",
       "plm",
       "plmm",
       "polr",
@@ -118,6 +141,7 @@ is_model <- function(x) {
       "stanreg",
       "survfit",
       "survreg",
+      "survPresmooth",
       "svyglm",
       "svyolr",
       "tobit",
