@@ -3,11 +3,8 @@ if (require("testthat") &&
   require("mgcv")) {
   context("insight, model_info")
 
-  dat <- gamSim(1,
-    n = 400,
-    dist = "normal",
-    scale = 2
-  )
+  set.seed(123)
+  dat <- gamSim(1, n = 400, dist = "normal", scale = 2)
   m1 <- mgcv::gam(y ~ s(x0) + s(x1) + s(x2) + s(x3), data = dat)
 
   m2 <- download_model("gam_zi_1")
@@ -176,6 +173,6 @@ if (require("testthat") &&
   })
 
   test_that("find_statistic", {
-    expect_null(find_statistic(m1))
+    expect_identical(find_statistic(m1), "t-statistic")
   })
 }
