@@ -1,10 +1,16 @@
-if (require("testthat") && require("insight") && require("glmmTMB")) {
+if (require("testthat") &&
+  require("insight") &&
+  require("glmmTMB")) {
   context("insight, model_info")
 
   data(Salamanders)
   Salamanders$cover <- abs(Salamanders$cover)
 
-  m1 <- glm(count ~ mined + log(cover) + sample, family = poisson, data = Salamanders)
+  m1 <-
+    glm(count ~ mined + log(cover) + sample,
+      family = poisson,
+      data = Salamanders
+    )
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_poisson)
@@ -15,7 +21,10 @@ if (require("testthat") && require("insight") && require("glmmTMB")) {
 
   test_that("find_predictors", {
     expect_identical(find_predictors(m1), list(conditional = c("mined", "cover", "sample")))
-    expect_identical(find_predictors(m1, flatten = TRUE), c("mined", "cover", "sample"))
+    expect_identical(
+      find_predictors(m1, flatten = TRUE),
+      c("mined", "cover", "sample")
+    )
     expect_null(find_predictors(m1, effects = "random"))
   })
 
@@ -45,7 +54,10 @@ if (require("testthat") && require("insight") && require("glmmTMB")) {
 
   test_that("get_data", {
     expect_equal(nrow(get_data(m1)), 644)
-    expect_equal(colnames(get_data(m1)), c("count", "mined", "cover", "sample"))
+    expect_equal(
+      colnames(get_data(m1)),
+      c("count", "mined", "cover", "sample")
+    )
   })
 
   test_that("find_formula", {
@@ -57,8 +69,17 @@ if (require("testthat") && require("insight") && require("glmmTMB")) {
   })
 
   test_that("find_variables", {
-    expect_equal(find_variables(m1), list(response = "count", conditional = c("mined", "cover", "sample")))
-    expect_equal(find_variables(m1, flatten = TRUE), c("count", "mined", "cover", "sample"))
+    expect_equal(
+      find_variables(m1),
+      list(
+        response = "count",
+        conditional = c("mined", "cover", "sample")
+      )
+    )
+    expect_equal(
+      find_variables(m1, flatten = TRUE),
+      c("count", "mined", "cover", "sample")
+    )
   })
 
   test_that("n_obs", {
@@ -77,7 +98,10 @@ if (require("testthat") && require("insight") && require("glmmTMB")) {
       )
     )
     expect_equal(nrow(get_parameters(m1)), 4)
-    expect_equal(get_parameters(m1)$parameter, c("(Intercept)", "minedno", "log(cover)", "sample"))
+    expect_equal(
+      get_parameters(m1)$parameter,
+      c("(Intercept)", "minedno", "log(cover)", "sample")
+    )
   })
 
   test_that("is_multivariate", {
@@ -97,4 +121,8 @@ if (require("testthat") && require("insight") && require("glmmTMB")) {
   test_that("find_algorithm", {
     expect_equal(find_algorithm(m1), list(algorithm = "ML"))
   })
+
+  test_that("find_statistic", {
+    expect_identical(find_statistic(m1), "z-statistic")
+  })
 }
