@@ -1,17 +1,24 @@
-if (require("testthat") && require("insight") && require("nlme")) {
+if (require("testthat") &&
+  require("insight") &&
+  require("nlme")) {
   context("insight, model_info")
 
   data(Ovary)
-  m1 <- gls(follicles ~ sin(2 * pi * Time) + cos(2 * pi * Time), Ovary,
-    correlation = corAR1(form = ~ 1 | Mare)
-  )
+  m1 <-
+    gls(follicles ~ sin(2 * pi * Time) + cos(2 * pi * Time),
+      Ovary,
+      correlation = corAR1(form = ~ 1 | Mare)
+    )
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_linear)
   })
 
   test_that("find_predictors", {
-    expect_identical(find_predictors(m1), list(conditional = "Time", correlation = "Mare"))
+    expect_identical(
+      find_predictors(m1),
+      list(conditional = "Time", correlation = "Mare")
+    )
     expect_identical(find_predictors(m1, flatten = TRUE), c("Time", "Mare"))
     expect_null(find_predictors(m1, effects = "random"))
   })
@@ -41,21 +48,39 @@ if (require("testthat") && require("insight") && require("nlme")) {
   })
 
   test_that("find_terms", {
-    expect_equal(find_terms(m1), list(
-      response = "follicles",
-      conditional = c("sin(2 * pi * Time)", "cos(2 * pi * Time)"),
-      correlation = c("1", "Mare")
-    ))
-    expect_equal(find_terms(m1, flatten = TRUE), c("follicles", "sin(2 * pi * Time)", "cos(2 * pi * Time)", "1", "Mare"))
+    expect_equal(
+      find_terms(m1),
+      list(
+        response = "follicles",
+        conditional = c("sin(2 * pi * Time)", "cos(2 * pi * Time)"),
+        correlation = c("1", "Mare")
+      )
+    )
+    expect_equal(
+      find_terms(m1, flatten = TRUE),
+      c(
+        "follicles",
+        "sin(2 * pi * Time)",
+        "cos(2 * pi * Time)",
+        "1",
+        "Mare"
+      )
+    )
   })
 
   test_that("find_variables", {
-    expect_equal(find_variables(m1), list(
-      response = "follicles",
-      conditional = "Time",
-      correlation = "Mare"
-    ))
-    expect_equal(find_variables(m1, flatten = TRUE), c("follicles", "Time", "Mare"))
+    expect_equal(
+      find_variables(m1),
+      list(
+        response = "follicles",
+        conditional = "Time",
+        correlation = "Mare"
+      )
+    )
+    expect_equal(
+      find_variables(m1, flatten = TRUE),
+      c("follicles", "Time", "Mare")
+    )
   })
 
   test_that("n_obs", {
@@ -74,10 +99,17 @@ if (require("testthat") && require("insight") && require("nlme")) {
       )
     )
     expect_equal(nrow(get_parameters(m1)), 3)
-    expect_equal(get_parameters(m1)$parameter, c("(Intercept)", "sin(2 * pi * Time)", "cos(2 * pi * Time)"))
+    expect_equal(
+      get_parameters(m1)$parameter,
+      c("(Intercept)", "sin(2 * pi * Time)", "cos(2 * pi * Time)")
+    )
   })
 
   test_that("is_multivariate", {
     expect_false(is_multivariate(m1))
   })
+
+  test_that("find_statistic", {
+    expect_identical(find_statistic(m1), "t-statistic")
+  })
 }
