@@ -1,11 +1,16 @@
-if (require("testthat") && require("insight") && require("stats")) {
+if (require("testthat") &&
+  require("insight") &&
+  require("stats")) {
   context("insight, lm")
 
   data(iris)
   data(mtcars)
 
   m1 <- lm(Sepal.Length ~ Petal.Width + Species, data = iris)
-  m2 <- lm(log(mpg) ~ log(hp) + cyl + I(cyl^2) + poly(wt, degree = 2, raw = TRUE), data = mtcars)
+  m2 <-
+    lm(log(mpg) ~ log(hp) + cyl + I(cyl^2) + poly(wt, degree = 2, raw = TRUE),
+      data = mtcars
+    )
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_linear)
@@ -14,7 +19,10 @@ if (require("testthat") && require("insight") && require("stats")) {
 
   test_that("find_predictors", {
     expect_identical(find_predictors(m1), list(conditional = c("Petal.Width", "Species")))
-    expect_identical(find_predictors(m1, flatten = TRUE), c("Petal.Width", "Species"))
+    expect_identical(
+      find_predictors(m1, flatten = TRUE),
+      c("Petal.Width", "Species")
+    )
     expect_null(find_predictors(m1, effects = "random"))
 
     expect_identical(find_predictors(m2), list(conditional = c("hp", "cyl", "wt")))
@@ -34,7 +42,10 @@ if (require("testthat") && require("insight") && require("stats")) {
 
   test_that("get_data", {
     expect_equal(nrow(get_data(m1)), 150)
-    expect_equal(colnames(get_data(m1)), c("Sepal.Length", "Petal.Width", "Species"))
+    expect_equal(
+      colnames(get_data(m1)),
+      c("Sepal.Length", "Petal.Width", "Species")
+    )
     expect_equal(nrow(get_data(m2)), 32)
     expect_equal(colnames(get_data(m2)), c("mpg", "hp", "cyl", "wt"))
   })
@@ -49,28 +60,94 @@ if (require("testthat") && require("insight") && require("stats")) {
     expect_length(find_formula(m2), 1)
     expect_equal(
       find_formula(m2),
-      list(conditional = as.formula("log(mpg) ~ log(hp) + cyl + I(cyl^2) + poly(wt, degree = 2, raw = TRUE)"))
+      list(
+        conditional = as.formula(
+          "log(mpg) ~ log(hp) + cyl + I(cyl^2) + poly(wt, degree = 2, raw = TRUE)"
+        )
+      )
     )
   })
 
   test_that("find_terms", {
-    expect_equal(find_terms(m1), list(response = "Sepal.Length", conditional = c("Petal.Width", "Species")))
-    expect_equal(find_terms(m2), list(response = "log(mpg)", conditional = c("log(hp)", "cyl", "I(cyl^2)", "poly(wt, degree = 2, raw = TRUE)")))
-    expect_equal(find_terms(m1, flatten = TRUE), c("Sepal.Length", "Petal.Width", "Species"))
-    expect_equal(find_terms(m2, flatten = TRUE), c("log(mpg)", "log(hp)", "cyl", "I(cyl^2)", "poly(wt, degree = 2, raw = TRUE)"))
+    expect_equal(
+      find_terms(m1),
+      list(
+        response = "Sepal.Length",
+        conditional = c("Petal.Width", "Species")
+      )
+    )
+    expect_equal(
+      find_terms(m2),
+      list(
+        response = "log(mpg)",
+        conditional = c(
+          "log(hp)",
+          "cyl",
+          "I(cyl^2)",
+          "poly(wt, degree = 2, raw = TRUE)"
+        )
+      )
+    )
+    expect_equal(
+      find_terms(m1, flatten = TRUE),
+      c("Sepal.Length", "Petal.Width", "Species")
+    )
+    expect_equal(
+      find_terms(m2, flatten = TRUE),
+      c(
+        "log(mpg)",
+        "log(hp)",
+        "cyl",
+        "I(cyl^2)",
+        "poly(wt, degree = 2, raw = TRUE)"
+      )
+    )
   })
 
   test_that("find_variables", {
-    expect_equal(find_variables(m1), list(response = "Sepal.Length", conditional = c("Petal.Width", "Species")))
-    expect_equal(find_variables(m2), list(response = "mpg", conditional = c("hp", "cyl", "wt")))
-    expect_equal(find_variables(m1, flatten = TRUE), c("Sepal.Length", "Petal.Width", "Species"))
-    expect_equal(find_variables(m2, flatten = TRUE), c("mpg", "hp", "cyl", "wt"))
+    expect_equal(
+      find_variables(m1),
+      list(
+        response = "Sepal.Length",
+        conditional = c("Petal.Width", "Species")
+      )
+    )
+    expect_equal(find_variables(m2), list(
+      response = "mpg",
+      conditional = c("hp", "cyl", "wt")
+    ))
+    expect_equal(
+      find_variables(m1, flatten = TRUE),
+      c("Sepal.Length", "Petal.Width", "Species")
+    )
+    expect_equal(
+      find_variables(m2, flatten = TRUE),
+      c("mpg", "hp", "cyl", "wt")
+    )
   })
 
   test_that("find_parameters", {
-    expect_equal(find_parameters(m1), list(conditional = c("(Intercept)", "Petal.Width", "Speciesversicolor", "Speciesvirginica")))
+    expect_equal(
+      find_parameters(m1),
+      list(
+        conditional = c(
+          "(Intercept)",
+          "Petal.Width",
+          "Speciesversicolor",
+          "Speciesvirginica"
+        )
+      )
+    )
     expect_equal(nrow(get_parameters(m1)), 4)
-    expect_equal(get_parameters(m1)$parameter, c("(Intercept)", "Petal.Width", "Speciesversicolor", "Speciesvirginica"))
+    expect_equal(
+      get_parameters(m1)$parameter,
+      c(
+        "(Intercept)",
+        "Petal.Width",
+        "Speciesversicolor",
+        "Speciesvirginica"
+      )
+    )
   })
 
   test_that("linkfun", {
@@ -102,20 +179,40 @@ if (require("testthat") && require("insight") && require("stats")) {
 
   data("DNase")
   DNase1 <- subset(DNase, Run == 1)
-  m3 <- stats::nls(density ~ stats::SSlogis(log(conc), Asym, xmid, scal), DNase1)
+  m3 <-
+    stats::nls(
+      density ~ stats::SSlogis(log(conc), Asym, xmid, scal),
+      DNase1,
+      start = list(
+        Asym = 1,
+        xmid = 1,
+        scal = 1
+      )
+    )
 
   ## Dobson (1990) Page 93: Randomized Controlled Trial :
-  counts <- c(18,17,15,20,10,20,25,13,12)
-  outcome <- gl(3,1,9)
-  treatment <- gl(3,3)
+  counts <- c(18, 17, 15, 20, 10, 20, 25, 13, 12)
+  outcome <- gl(3, 1, 9)
+  treatment <- gl(3, 3)
   m4 <- glm(counts ~ outcome + treatment, family = poisson())
 
   test_that("is_model", {
-    expect_false(is_model(m3))
+    expect_true(is_model(m3))
+  })
+
+  test_that("is_model", {
+    expect_false(is_model_supported(m3))
   })
 
   test_that("all_models_equal", {
     expect_false(all_models_equal(m1, m2, m3))
     expect_false(all_models_equal(m1, m2, m4))
   })
+
+  test_that("find_statistic", {
+    expect_identical(find_statistic(m1), "t-statistic")
+    expect_identical(find_statistic(m2), "t-statistic")
+    expect_identical(find_statistic(m3), "t-statistic")
+    expect_identical(find_statistic(m4), "z-statistic")
+  })
 }
