@@ -4,8 +4,7 @@ if (require("testthat") &&
   context("insight, model_info")
 
   data(sex2)
-  m1 <-
-    logistf(case ~ age + oc + vic + vicl + vis + dia, data = sex2)
+  m1 <- logistf(case ~ age + oc + vic + vicl + vis + dia, data = sex2)
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_binomial)
