@@ -1,4 +1,6 @@
-if (require("testthat") && require("insight") && require("MASS")) {
+if (require("testthat") &&
+  require("insight") &&
+  require("MASS")) {
   context("insight, polr")
 
   data(housing, package = "MASS")
@@ -11,7 +13,10 @@ if (require("testthat") && require("insight") && require("MASS")) {
 
   test_that("find_predictors", {
     expect_identical(find_predictors(m1), list(conditional = c("Infl", "Type", "Cont")))
-    expect_identical(find_predictors(m1, flatten = TRUE), c("Infl", "Type", "Cont"))
+    expect_identical(
+      find_predictors(m1, flatten = TRUE),
+      c("Infl", "Type", "Cont")
+    )
     expect_null(find_predictors(m1, effects = "random"))
   })
 
@@ -25,7 +30,10 @@ if (require("testthat") && require("insight") && require("MASS")) {
 
   test_that("get_data", {
     expect_equal(nrow(get_data(m1)), 72)
-    expect_equal(colnames(get_data(m1)), c("Sat", "Infl", "Type", "Cont", "(weights)", "Freq"))
+    expect_equal(
+      colnames(get_data(m1)),
+      c("Sat", "Infl", "Type", "Cont", "(weights)", "Freq")
+    )
   })
 
   test_that("find_formula", {
@@ -37,8 +45,14 @@ if (require("testthat") && require("insight") && require("MASS")) {
   })
 
   test_that("find_terms", {
-    expect_equal(find_terms(m1), list(response = "Sat", conditional = c("Infl", "Type", "Cont")))
-    expect_equal(find_terms(m1, flatten = TRUE), c("Sat", "Infl", "Type", "Cont"))
+    expect_equal(find_terms(m1), list(
+      response = "Sat",
+      conditional = c("Infl", "Type", "Cont")
+    ))
+    expect_equal(
+      find_terms(m1, flatten = TRUE),
+      c("Sat", "Infl", "Type", "Cont")
+    )
   })
 
   test_that("n_obs", {
@@ -53,9 +67,19 @@ if (require("testthat") && require("insight") && require("MASS")) {
   test_that("find_parameters", {
     expect_equal(
       find_parameters(m1),
-      list(conditional =
-             c("Intercept: Low|Medium", "Intercept: Medium|High", "InflMedium",
-               "InflHigh", "TypeApartment", "TypeAtrium", "TypeTerrace", "ContHigh"))
+      list(
+        conditional =
+          c(
+            "Intercept: Low|Medium",
+            "Intercept: Medium|High",
+            "InflMedium",
+            "InflHigh",
+            "TypeApartment",
+            "TypeAtrium",
+            "TypeTerrace",
+            "ContHigh"
+          )
+      )
     )
   })
 
@@ -63,11 +87,33 @@ if (require("testthat") && require("insight") && require("MASS")) {
     expect_equal(
       get_parameters(m1),
       data.frame(
-        parameter = c("Intercept: Low|Medium", "Intercept: Medium|High", "InflMedium", "InflHigh", "TypeApartment", "TypeAtrium", "TypeTerrace", "ContHigh"),
-        estimate = c(-0.4961353438375, 0.690708290379271, 0.566393738890106, 1.28881906381232, -0.572350146429611, -0.366186566153346, -1.09101490767244, 0.360284149947385),
+        parameter = c(
+          "Intercept: Low|Medium",
+          "Intercept: Medium|High",
+          "InflMedium",
+          "InflHigh",
+          "TypeApartment",
+          "TypeAtrium",
+          "TypeTerrace",
+          "ContHigh"
+        ),
+        estimate = c(
+          -0.4961353438375,
+          0.690708290379271,
+          0.566393738890106,
+          1.28881906381232,
+          -0.572350146429611,
+          -0.366186566153346,
+          -1.09101490767244,
+          0.360284149947385
+        ),
         stringsAsFactors = FALSE,
         row.names = NULL
       )
     )
   })
+
+  test_that("find_statistic", {
+    expect_identical(find_statistic(m1), "t-statistic")
+  })
 }
