@@ -1,11 +1,16 @@
-if (require("testthat") && require("insight") && require("speedglm")) {
+if (require("testthat") &&
+  require("insight") &&
+  require("speedglm")) {
   context("insight, model_info")
 
   data(iris)
   data(mtcars)
 
   m1 <- speedlm(Sepal.Length ~ Petal.Width + Species, data = iris)
-  m2 <- speedlm(log(mpg) ~ log(hp) + cyl + I(cyl^2) + poly(wt, degree = 2, raw = TRUE), data = mtcars)
+  m2 <-
+    speedlm(log(mpg) ~ log(hp) + cyl + I(cyl^2) + poly(wt, degree = 2, raw = TRUE),
+      data = mtcars
+    )
 
   test_that("model_info", {
     expect_true(model_info(m1)$is_linear)
@@ -13,7 +18,10 @@ if (require("testthat") && require("insight") && require("speedglm")) {
 
   test_that("find_predictors", {
     expect_identical(find_predictors(m1), list(conditional = c("Petal.Width", "Species")))
-    expect_identical(find_predictors(m1, flatten = TRUE), c("Petal.Width", "Species"))
+    expect_identical(
+      find_predictors(m1, flatten = TRUE),
+      c("Petal.Width", "Species")
+    )
     expect_null(find_predictors(m1, effects = "random"))
   })
 
@@ -47,7 +55,10 @@ if (require("testthat") && require("insight") && require("speedglm")) {
 
   test_that("get_data", {
     expect_equal(nrow(get_data(m1)), 150)
-    expect_equal(colnames(get_data(m1)), c("Sepal.Length", "Petal.Width", "Species"))
+    expect_equal(
+      colnames(get_data(m1)),
+      c("Sepal.Length", "Petal.Width", "Species")
+    )
     expect_equal(colnames(get_data(m2)), c("mpg", "hp", "cyl", "wt"))
   })
 
@@ -59,14 +70,30 @@ if (require("testthat") && require("insight") && require("speedglm")) {
     )
     expect_equal(
       find_formula(m2),
-      list(conditional = as.formula("log(mpg) ~ log(hp) + cyl + I(cyl^2) + poly(wt, degree = 2, raw = TRUE)"))
+      list(
+        conditional = as.formula(
+          "log(mpg) ~ log(hp) + cyl + I(cyl^2) + poly(wt, degree = 2, raw = TRUE)"
+        )
+      )
     )
   })
 
   test_that("find_variables", {
-    expect_equal(find_variables(m1), list(response = "Sepal.Length", conditional = c("Petal.Width", "Species")))
-    expect_equal(find_variables(m1, flatten = TRUE), c("Sepal.Length", "Petal.Width", "Species"))
-    expect_equal(find_variables(m2, flatten = TRUE), c("mpg", "hp", "cyl", "wt"))
+    expect_equal(
+      find_variables(m1),
+      list(
+        response = "Sepal.Length",
+        conditional = c("Petal.Width", "Species")
+      )
+    )
+    expect_equal(
+      find_variables(m1, flatten = TRUE),
+      c("Sepal.Length", "Petal.Width", "Species")
+    )
+    expect_equal(
+      find_variables(m2, flatten = TRUE),
+      c("mpg", "hp", "cyl", "wt")
+    )
   })
 
   test_that("n_obs", {
@@ -78,17 +105,37 @@ if (require("testthat") && require("insight") && require("speedglm")) {
     expect_equal(
       find_parameters(m1),
       list(
-        conditional = c("(Intercept)", "Petal.Width", "Speciesversicolor", "Speciesvirginica")
+        conditional = c(
+          "(Intercept)",
+          "Petal.Width",
+          "Speciesversicolor",
+          "Speciesvirginica"
+        )
       )
     )
     expect_equal(
       find_parameters(m2),
       list(
-        conditional = c("(Intercept)", "log(hp)", "cyl", "I(cyl^2)", "poly(wt, degree = 2, raw = TRUE)1", "poly(wt, degree = 2, raw = TRUE)2")
+        conditional = c(
+          "(Intercept)",
+          "log(hp)",
+          "cyl",
+          "I(cyl^2)",
+          "poly(wt, degree = 2, raw = TRUE)1",
+          "poly(wt, degree = 2, raw = TRUE)2"
+        )
       )
     )
     expect_equal(nrow(get_parameters(m1)), 4)
-    expect_equal(get_parameters(m1)$parameter, c("(Intercept)", "Petal.Width", "Speciesversicolor", "Speciesvirginica"))
+    expect_equal(
+      get_parameters(m1)$parameter,
+      c(
+        "(Intercept)",
+        "Petal.Width",
+        "Speciesversicolor",
+        "Speciesvirginica"
+      )
+    )
   })
 
   test_that("is_multivariate", {
@@ -107,7 +154,12 @@ if (require("testthat") && require("insight") && require("speedglm")) {
       find_terms(m2),
       list(
         response = "log(mpg)",
-        conditional = c("log(hp)", "cyl", "I(cyl^2)", "poly(wt, degree = 2, raw = TRUE)")
+        conditional = c(
+          "log(hp)",
+          "cyl",
+          "I(cyl^2)",
+          "poly(wt, degree = 2, raw = TRUE)"
+        )
       )
     )
   })
@@ -115,4 +167,9 @@ if (require("testthat") && require("insight") && require("speedglm")) {
   test_that("find_algorithm", {
     expect_equal(find_algorithm(m1), list(algorithm = "eigen"))
   })
+
+  test_that("find_statistic", {
+    expect_identical(find_statistic(m1), "t-statistic")
+    expect_identical(find_statistic(m2), "t-statistic")
+  })
 }
